@@ -7,7 +7,7 @@ from autofeat import FeatureSelector
 
 # import time as timecounter
 
-from .columns import targets, time_columns, label_encoders, error_codes, groups, exclude, predictors, item_to_group, group_starts_with
+from .columns import targets, label_encoders, error_codes, groups, predictors, item_to_group, group_starts_with
 
 
 def encode(df, output_df, label_encoders, cols):
@@ -106,16 +106,6 @@ def load_targets(df, Y, targets):
         Y[y] = df[targets[y]].mean(axis=1)
     return
 
-
-# TO DO: to delete
-def time2num(df, columns, cols):
-    for column in columns:
-        if column in cols:
-            df[column] = df[column].astype(str)
-            df[column] = df[column].apply(lambda x: np.dot(np.array(x.split(':'), dtype=float), np.array([1.0, 1.0/60])))
-    return
-
-
 def flatten(t):
     # ex: [1, 2, 2, [3], [4, 5]] => [1, 2, 2, 3, 4, 5]
     # but: [1, 2, 2, [3], [4, [5]]] => [1, 2, 2, 3, 4, [5]]
