@@ -263,10 +263,9 @@ class DB_Connector:
         return df.iloc[0][0]
 
     def update_end(self, model_id, end):
-        query = '''insert into
-                    Models(model_id, end)
-                    values (%s, \'%s\')'''
-        self.cursor.execute(query, (int(model_id), end))
+        query = '''update Models set \"end\"=%s
+                    where model_id=%s'''
+        self.cursor.execute(query, (end, int(model_id)))
         self.conn.commit()
 
     # TO DO: to rewrite
