@@ -5,8 +5,8 @@ import io
 import os
 import pickle
 
-def save_model(model, model_id:int, target_id:int):
-    initial_dir = os.getcwd()
+def save_model(PATH, model, model_id:int, target_id:int):
+    initial_dir = PATH
     check = os.path.join(initial_dir, r'models')
     if not os.path.exists(check):
         os.makedirs(check)
@@ -24,8 +24,9 @@ def save_model(model, model_id:int, target_id:int):
     os.chdir(initial_dir)
 
 
-def get_models(model_id:int):
-    initial_dir = os.getcwd()
+def get_models(PATH, model_id:int):
+
+    initial_dir = PATH
     model_dir = os.path.join(initial_dir, r'models')
     model_dir = os.path.join(model_dir, f'{model_id}')
     os.chdir(model_dir)
